@@ -6,21 +6,17 @@
  * Date        : 2009-08-03
  * Description : digiKam config header
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONFIG_H
-#define DIGIKAM_CONFIG_H
+#pragma once
 
 /* Define to 1 if you have KDEPIM shared library installed */
 #define HAVE_AKONADICONTACT 1
 
-/* Define to 1 if an external liblqr-1 shared library have been found */
-#define HAVE_LIBLQR_1 1
-
 /* Define to 1 if an external lensfun shared library have been found */
 #define HAVE_LENSFUN 1
 
@@ -34,7 +30,7 @@
 #define HAVE_KSANE 1
 
 /* Define to 1 if an external Marble shared library have been found */
-#define HAVE_MARBLE 1
+#define HAVE_GEOLOCATION 1
 
 /* Define to 1 if an external Eigen3 shared library have been found */
 #define HAVE_EIGEN3 1
@@ -54,6 +50,9 @@
 /* Define to 1 if Jasper shared library is installed */
 #define HAVE_JASPER 1
 
+/* Define to 1 if libjxl shared library is installed */
+#define HAVE_JXL 1
+
 /* Define to 1 if libgphoto2 2.5 shared library is installed */
 #define HAVE_GPHOTO25 1
 
@@ -78,9 +77,6 @@
 /* Define to 1 if Panorama tool is supported */
 #define HAVE_PANORAMA 1
 
-/* Define to 1 if VKontakte tool is supported */
-/* #undef HAVE_VKONTAKTE */
-
 /* Define to 1 if HTMLGallery tool is supported */
 #define HAVE_HTMLGALLERY 1
 
@@ -105,32 +101,13 @@
 /* Define to 1 if changing application styles is supported */
 #define HAVE_APPSTYLE_SUPPORT 1
 
-/* Define to 1 if system use QtWebEngine */
-#define HAVE_QWEBENGINE 1
+/* Define to 1 if system use QtMultimedia */
+#define HAVE_QTMULTIMEDIA 1
 
 /* Define to 1 if system use QtXmlPatterns */
-#define HAVE_QTXMLPATTERNS 1
+/* #undef HAVE_QTXMLPATTERNS */
 
 /* Define to 1 if ImageMagick codecs are supported */
 #define HAVE_IMAGE_MAGICK 1
 
-/* Defines to 1 if the Dr. Mingw crash handler should be used */
-/* #undef HAVE_DRMINGW */
-
-#define LIBEXEC_INSTALL_DIR "/usr/lib/libexec"
-
-/*
- * Disable indeep warnings from Visual Studio C++
- */
-#if defined(_MSC_VER)
-// To disable warnings about no suitable definition provided for explicit template instantiation request.
-#pragma warning(disable : 4661)
-// To disable warnings about deprecated POSIX methods().
-#pragma warning(disable : 4996)
-// To disable warnings about qualifier applied to reference type ignored.
-#pragma warning(disable : 4181)
-// To disable warnings about 'storage-class-keyword' no longer supported as storage class.
-#pragma warning(disable : 5033)
-#endif
-
-#endif // DIGIKAM_CONFIG_H
+#define LIBEXEC_INSTALL_DIR "/usr/libexec"
